==> nipper-0.10.4.tgz: nipper-0.10.4/nipper-defaults.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void processDefaults(struct nipperConfig *nipper)
{
	// Variables...
	struct lineConfig *linePointer;
	struct interfaceConfig *interfacePointer;
	struct passiveStruct *passivePointer;
	struct eigrpConfig *eigrpPointer;
	struct eigrpAutonStruct *eigrpAutonPointer;
	struct bgpInterStruct *bgpInterPointer;
	struct bgpConfig *bgpPointer;
	struct ospfInterStruct *ospfInterPointer;
	struct ospfConfig *ospfPointer;
	int setting;
	int setting2;

	switch(nipper->deviceType)
	{
		// Switch / Router / IOS
		case type_ios_switch:
		case type_ios_router:
		case type_ios_catalyst:

			// Time Zones...
			if (nipper->timeZones == unconfigured)
				nipper->timeZones = true;

			// Minimum Password Length
			if (nipper->ios->passwordMinLength == -1)
			{
				if ((nipper->versionMajor == 12) && (nipper->versionMinor > 2))
					nipper->ios->passwordMinLength = 6;
			}

			// BGP Passive
			if (nipper->ios->bgp != 0)
			{
				bgpPointer = nipper->ios->bgp;
				while (bgpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						bgpInterPointer = bgpInterfaceConfig(interfacePointer, bgpPointer->autonomousNo);
						passivePointer = bgpPointer->passive;
						while (passivePointer != 0)
						{
							if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
								bgpInterPointer->passive = passivePointer->passive;
							passivePointer = passivePointer->next;
						}
						interfacePointer = interfacePointer->next;
					}
					bgpPointer = bgpPointer->next;
				}
				bgpPointer = nipper->ios->bgp;
				while (bgpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						bgpInterPointer = bgpInterfaceConfig(interfacePointer, bgpPointer->autonomousNo);
						if (bgpInterPointer->passive == unconfigured)
							bgpInterPointer->passive = bgpPointer->defaultPassive;
						interfacePointer = interfacePointer->next;
					}
					bgpPointer = bgpPointer->next;
				}
			}

			// EIGRP Passive
			if (nipper->ios->eigrp != 0)
			{
				eigrpPointer = nipper->ios->eigrp;
				while (eigrpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						eigrpAutonPointer = eigrpInterfaceConfig(interfacePointer, eigrpPointer->process);
						passivePointer = eigrpPointer->passive;
						while (passivePointer != 0)
						{
							if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
								eigrpAutonPointer->passive = passivePointer->passive;
							passivePointer = passivePointer->next;
						}
						interfacePointer = interfacePointer->next;
					}
					eigrpPointer = eigrpPointer->next;
				}
				eigrpPointer = nipper->ios->eigrp;
				while (eigrpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						eigrpAutonPointer = eigrpInterfaceConfig(interfacePointer, eigrpPointer->process);
						if (eigrpAutonPointer->passive == unconfigured)
							eigrpAutonPointer->passive = eigrpPointer->defaultPassive;
						interfacePointer = interfacePointer->next;
					}
					eigrpPointer = eigrpPointer->next;
				}
			}

			// OSPF Passive
			if (nipper->ios->ospf != 0)
			{
				ospfPointer = nipper->ios->ospf;
				while (ospfPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						ospfInterPointer = ospfInterfaceConfig(interfacePointer, ospfPointer->processID);
						passivePointer = ospfPointer->passive;
						while (passivePointer != 0)
						{
							if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
								bgpInterPointer->passive = passivePointer->passive;
							passivePointer = passivePointer->next;
						}
						interfacePointer = interfacePointer->next;
					}
					ospfPointer = ospfPointer->next;
				}
				ospfPointer = nipper->ios->ospf;
				while (ospfPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						ospfInterPointer = ospfInterfaceConfig(interfacePointer, ospfPointer->processID);
						if (ospfInterPointer->passive == unconfigured)
							ospfInterPointer->passive = ospfPointer->defaultPassive;
						interfacePointer = interfacePointer->next;
					}
					ospfPointer = ospfPointer->next;
				}
			}

			// RIP Version and Passive
			if (nipper->ios->rip != 0)
			{
				switch (nipper->ios->rip->version)
				{
					case rip_version1:
						setting = rip_version1;			// Send
						setting2 = rip_version1;		// Receive
						break;
					case rip_version2:
						setting = rip_version2;			// Send
						setting2 = rip_version2;		// Receive
						break;
					default:
						setting = rip_version1;			// Send
						setting2 = rip_version1and2;	// Receive
						break;
				}
				interfacePointer = nipper->ios->interface;
				while (interfacePointer != 0)
				{
					passivePointer = nipper->ios->rip->passive;
					while (passivePointer != 0)
					{
						if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
							interfacePointer->ripPassive = passivePointer->passive;
						passivePointer = passivePointer->next;
					}
					if (interfacePointer->ripSendVersion == rip_version_global)
						interfacePointer->ripSendVersion = setting;
					if (interfacePointer->ripReceiveVersion == rip_version_global)
						interfacePointer->ripReceiveVersion = setting2;
					interfacePointer = interfacePointer->next;
				}
				interfacePointer = nipper->ios->interface;
				while (interfacePointer != 0)
				{
					if (interfacePointer->ripPassive == unconfigured)
						interfacePointer->ripPassive = nipper->ios->rip->defaultPassive;
					interfacePointer = interfacePointer->next;
				}
			}

			// Finger
			if (nipper->ios->finger == unconfigured)
			{
				if (((nipper->versionMajor > 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor > 2))) && ((nipper->versionMajor < 12) || ((nipper->versionMajor == 12) && (nipper->versionMinor < 1))))
					nipper->ios->finger = true;
				else
					nipper->ios->finger = false;
			}

			// TCP Small Servers
			if (nipper->ios->tcpSmallServers == unconfigured)
			{
				if ((nipper->versionMajor < 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor < 3)))
					nipper->ios->tcpSmallServers = true;
				else
					nipper->ios->tcpSmallServers = false;
			}

			// UDP Small Servers
			if (nipper->ios->udpSmallServers == unconfigured)
			{
				if ((nipper->versionMajor < 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor < 3)))
					nipper->ios->udpSmallServers = true;
				else
					nipper->ios->udpSmallServers = false;
			}

			// Transport Input Lines Telnet...
			if ((nipper->versionMajor < 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor == 0)))
				setting = true;
			else
				setting = false;
			linePointer = nipper->ios->line;
			while (linePointer != 0)
			{
				if (linePointer->telnet == unconfigured)
					linePointer->telnet = setting;
				linePointer = linePointer->next;
			}
			break;

		// Firewall / PIX
		case type_pix_firewall:
		case type_asa_firewall:
		case type_fwsm_firewall:
			break;

		// Catalyst / NMP
		case type_nmp_catalyst:
		case type_cos_catalyst:
			break;

		// Cisco CSS
		case type_css_filter:

			// ACL Enabled. If unconfigured, it depends on if there are ACL configured.
			if ((nipper->css->aclEnabled == unconfigured) && (nipper->css->acl == 0))
				nipper->css->aclEnabled = false;
			else if ((nipper->css->aclEnabled == unconfigured) && (nipper->css->acl != 0))
				nipper->css->aclEnabled = true;
			break;

		// ScreenOS
		case type_sos_firewall:
			break;
	}
}

==> nipper-0.10.5.tgz: nipper-0.10.5/nipper-defaults.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by the following authors:                   *
 *                                                                         *
 *       Ian Ventura-Whiting (fizz@titania.co.uk)                          *
 *       David Croft                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void processDefaults(struct nipperConfig *nipper)
{
	// Variables...
	struct lineConfig *linePointer = 0;
	struct interfaceConfig *interfacePointer = 0;
	struct passiveStruct *passivePointer = 0;
	struct eigrpConfig *eigrpPointer = 0;
	struct eigrpAutonStruct *eigrpAutonPointer = 0;
	struct bgpInterStruct *bgpInterPointer = 0;
	struct bgpConfig *bgpPointer = 0;
	struct ospfInterStruct *ospfInterPointer = 0;
	struct ospfConfig *ospfPointer = 0;
	int setting = 0;
	int setting2 = 0;

	switch(nipper->deviceType)
	{
		// Switch / Router / IOS
		case type_ios_switch:
		case type_ios_router:
		case type_ios_catalyst:

			// Time Zones...
			if (nipper->timeZones == unconfigured)
				nipper->timeZones = true;

			// Minimum Password Length
			if (nipper->ios->passwordMinLength == -1)
			{
				if ((nipper->versionMajor == 12) && (nipper->versionMinor > 2))
					nipper->ios->passwordMinLength = 6;
			}

			// BGP Passive
			if (nipper->ios->bgp != 0)
			{
				bgpPointer = nipper->ios->bgp;
				while (bgpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						bgpInterPointer = bgpInterfaceConfig(interfacePointer, bgpPointer->autonomousNo);
						passivePointer = bgpPointer->passive;
						while (passivePointer != 0)
						{
							if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
								bgpInterPointer->passive = passivePointer->passive;
							passivePointer = passivePointer->next;
						}
						interfacePointer = interfacePointer->next;
					}
					bgpPointer = bgpPointer->next;
				}
				bgpPointer = nipper->ios->bgp;
				while (bgpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						bgpInterPointer = bgpInterfaceConfig(interfacePointer, bgpPointer->autonomousNo);
						if (bgpInterPointer->passive == unconfigured)
							bgpInterPointer->passive = bgpPointer->defaultPassive;
						interfacePointer = interfacePointer->next;
					}
					bgpPointer = bgpPointer->next;
				}
			}

			// EIGRP Passive
			if (nipper->ios->eigrp != 0)
			{
				eigrpPointer = nipper->ios->eigrp;
				while (eigrpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						eigrpAutonPointer = eigrpInterfaceConfig(interfacePointer, eigrpPointer->process);
						passivePointer = eigrpPointer->passive;
						while (passivePointer != 0)
						{
							if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
								eigrpAutonPointer->passive = passivePointer->passive;
							passivePointer = passivePointer->next;
						}
						interfacePointer = interfacePointer->next;
					}
					eigrpPointer = eigrpPointer->next;
				}
				eigrpPointer = nipper->ios->eigrp;
				while (eigrpPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						eigrpAutonPointer = eigrpInterfaceConfig(interfacePointer, eigrpPointer->process);
						if (eigrpAutonPointer->passive == unconfigured)
							eigrpAutonPointer->passive = eigrpPointer->defaultPassive;
						interfacePointer = interfacePointer->next;
					}
					eigrpPointer = eigrpPointer->next;
				}
			}

			// OSPF Passive
			if (nipper->ios->ospf != 0)
			{
				ospfPointer = nipper->ios->ospf;
				while (ospfPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						ospfInterPointer = ospfInterfaceConfig(interfacePointer, ospfPointer->processID);
						passivePointer = ospfPointer->passive;
						while (passivePointer != 0)
						{
							if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
								ospfInterPointer->passive = passivePointer->passive;
							passivePointer = passivePointer->next;
						}
						interfacePointer = interfacePointer->next;
					}
					ospfPointer = ospfPointer->next;
				}
				ospfPointer = nipper->ios->ospf;
				while (ospfPointer != 0)
				{
					interfacePointer = nipper->ios->interface;
					while (interfacePointer != 0)
					{
						ospfInterPointer = ospfInterfaceConfig(interfacePointer, ospfPointer->processID);
						if (ospfInterPointer->passive == unconfigured)
							ospfInterPointer->passive = ospfPointer->defaultPassive;
						interfacePointer = interfacePointer->next;
					}
					ospfPointer = ospfPointer->next;
				}
			}

			// RIP Version and Passive
			if (nipper->ios->rip != 0)
			{
				switch (nipper->ios->rip->version)
				{
					case rip_version1:
						setting = rip_version1;			// Send
						setting2 = rip_version1;		// Receive
						break;
					case rip_version2:
						setting = rip_version2;			// Send
						setting2 = rip_version2;		// Receive
						break;
					default:
						setting = rip_version1;			// Send
						setting2 = rip_version1and2;	// Receive
						break;
				}
				interfacePointer = nipper->ios->interface;
				while (interfacePointer != 0)
				{
					passivePointer = nipper->ios->rip->passive;
					while (passivePointer != 0)
					{
						if (strcmp(passivePointer->interface, interfacePointer->name) == 0)
							interfacePointer->ripPassive = passivePointer->passive;
						passivePointer = passivePointer->next;
					}
					if (interfacePointer->ripSendVersion == rip_version_global)
						interfacePointer->ripSendVersion = setting;
					if (interfacePointer->ripReceiveVersion == rip_version_global)
						interfacePointer->ripReceiveVersion = setting2;
					interfacePointer = interfacePointer->next;
				}
				interfacePointer = nipper->ios->interface;
				while (interfacePointer != 0)
				{
					if (interfacePointer->ripPassive == unconfigured)
						interfacePointer->ripPassive = nipper->ios->rip->defaultPassive;
					interfacePointer = interfacePointer->next;
				}
			}

			// Finger
			if (nipper->ios->finger == unconfigured)
			{
				if (((nipper->versionMajor > 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor > 2))) && ((nipper->versionMajor < 12) || ((nipper->versionMajor == 12) && (nipper->versionMinor < 1))))
					nipper->ios->finger = true;
				else
					nipper->ios->finger = false;
			}

			// TCP Small Servers
			if (nipper->ios->tcpSmallServers == unconfigured)
			{
				if ((nipper->versionMajor < 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor < 3)))
					nipper->ios->tcpSmallServers = true;
				else
					nipper->ios->tcpSmallServers = false;
			}

			// UDP Small Servers
			if (nipper->ios->udpSmallServers == unconfigured)
			{
				if ((nipper->versionMajor < 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor < 3)))
					nipper->ios->udpSmallServers = true;
				else
					nipper->ios->udpSmallServers = false;
			}

			// Transport Input Lines Telnet...
			if ((nipper->versionMajor < 11) || ((nipper->versionMajor == 11) && (nipper->versionMinor == 0)))
				setting = true;
			else
				setting = false;
			linePointer = nipper->ios->line;
			while (linePointer != 0)
			{
				if (linePointer->telnet == unconfigured)
					linePointer->telnet = setting;
				linePointer = linePointer->next;
			}
			break;

		// Firewall / PIX
		case type_pix_firewall:
		case type_asa_firewall:
		case type_fwsm_firewall:
			break;

		// Catalyst / NMP
		case type_nmp_catalyst:
		case type_cos_catalyst:
			break;

		// Cisco CSS
		case type_css_filter:

			// ACL Enabled. If unconfigured, it depends on if there are ACL configured.
			if ((nipper->css->aclEnabled == unconfigured) && (nipper->css->acl == 0))
				nipper->css->aclEnabled = false;
			else if ((nipper->css->aclEnabled == unconfigured) && (nipper->css->acl != 0))
				nipper->css->aclEnabled = true;
			break;

		// ScreenOS
		case type_sos_firewall:
			break;
	}
}
